@@ -825,6 +825,7 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
 		     nil)))))
 
 (defvar enable-multibyte-characters)
+(defvar buffer-display-table)
 (defun vm-fsfemacs-nonmule-display-8bit-chars ()
   (cond ((and vm-fsfemacs-p 
 	      (or (not vm-fsfemacs-mule-p)
@@ -852,7 +853,9 @@ If HACK-ADDRESSES is t, then the strings are considered to be mail addresses,
 	(hex-digit-alist '((?0 .  0)  (?1 .  1)  (?2 .  2)  (?3 .  3)
 			   (?4 .  4)  (?5 .  5)  (?6 .  6)  (?7 .  7)
 			   (?8 .  8)  (?9 .  9)  (?A . 10)  (?B . 11)
-			   (?C . 12)  (?D . 13)  (?E . 14)  (?F . 15)))
+			   (?C . 12)  (?D . 13)  (?E . 14)  (?F . 15)
+			   (?a . 10)  (?b . 11)  (?c . 12)  (?d . 13)
+			   (?e . 14)  (?f . 15)))
 	char)
     (save-excursion
       (goto-char (point-min))
