@@ -90,8 +90,7 @@ mandatory."
 	;; need to do this after any frame creation because the
 	;; toolbar sets frame-specific height and width specifiers.
 	(set-buffer vm-summary-buffer)
-	(and (vm-toolbar-support-possible-p) vm-use-toolbar
-	     (vm-toolbar-install-toolbar)))
+	(vm-toolbar-install-or-uninstall-toolbar))
     (vm-display nil nil '(vm-summarize vm-summarize-other-frame)
 		(list this-command)))
   (vm-update-summary-and-mode-line))
@@ -154,7 +153,8 @@ mandatory."
 		      m
 		      (vm-mouse-set-mouse-track-highlight
 		       (vm-su-start-of m)
-		       (vm-su-end-of m))))
+		       (vm-su-end-of m)
+		       (vm-su-summary-mouse-track-overlay-of m))))
 		(vm-set-su-start-of m (vm-marker (vm-su-start-of m)))
 		(vm-set-su-end-of m (vm-marker (vm-su-end-of m)))
 		(setq mp (cdr mp))))
@@ -337,7 +337,9 @@ mandatory."
     ;; The local variable name `vm-su-message' is mandatory here for
     ;; the format s-expression to work.
     (let ((vm-su-message message))
-      (eval (cdr match)))))
+      (if (or tokenize (null vm-display-using-mime))
+	  (eval (cdr match))
+	(vm-decode-mime-encoded-words-in-string (eval (cdr match)))))))
 
 (defun vm-summary-compile-format (format tokenize)
   (let ((return-value (vm-summary-compile-format-1 format tokenize)))
@@ -744,25 +746,25 @@ mandatory."
 	(setq month (substring date (match-beginning 0) (match-end 0))))
     (if (string-match "[0-9]?[0-9]:[0-9][0-9]\\(:[0-9][0-9]\\)?" date)
 	(setq hour (substring date (match-beginning 0) (match-end 0))))
-    (if (or (string-match "[^a-z][+---][0-9][0-9][0-9][0-9]" date)
-	    (string-match "e[ds]t\\|c[ds]t\\|p[ds]t\\|m[ds]t" date)
-	    (string-match "ast\\|nst\\|met\\|eet\\|jst\\|bst\\|ut" date)
-	    (string-match "gmt\\([+---][0-9]+\\)?" date))
-	(setq timezone (substring date (match-beginning 0) (match-end 0))))
-    (while (string-match "\\(\\`\\|[^:+---0-9]\\|[a-z]-\\)[0-9]+\\(\\'\\|[^:]\\)"
-			 date start)
-      (setq string (substring date (match-end 1) (match-beginning 2))
+    (cond ((string-match "[^a-z][+---][0-9][0-9][0-9][0-9]" date)
+	   (setq timezone (substring date (1+ (match-beginning 0))
+				     (match-end 0))))
+	  ((or (string-match "e[ds]t\\|c[ds]t\\|p[ds]t\\|m[ds]t" date)
+	       (string-match "ast\\|nst\\|met\\|eet\\|jst\\|bst\\|ut" date)
+	       (string-match "gmt\\([+---][0-9]+\\)?" date))
+	   (setq timezone (substring date (match-beginning 0) (match-end 0)))))
+    (while (and (or (zerop (length monthday))
+		    (zerop (length year)))
+		(string-match "\\(^\\| \\)\\([0-9]+\\)\\($\\| \\)" date start))
+      (setq string (substring date (match-beginning 2) (match-end 2))
 	    start (match-end 0))
-      (cond ((string-match "\\`[4-9]." string)
-	     ;; Assume that any two digits less than 40 are a date and not
-	     ;; a year.  The world will surely end soon.
-	     (setq year (concat "19" string))
-	     ;; assume any 2-digit year before 1970 is really a date past
-	     ;; the year 2000.
-	     (if (< (string-to-int year) 1970)
-		 (setq year (int-to-string (+ 100 (string-to-int year))))))
-	    ((< (length string) 3)
+      (cond ((and (zerop (length monthday))
+		  (<= (length string) 2))
 	     (setq monthday string))
+	    ((= (length string) 2)
+	     (if (< (string-to-int string) 70)
+		 (setq year (concat "20" string))
+	       (setq year (concat "19" string))))
 	    (t (setq year string))))
     
     (aset vm-parse-date-workspace 0 weekday)
@@ -1484,12 +1486,13 @@ mandatory."
 	  (while dp
 	    (if (cdr vm-folders-summary-directories)
 		(insert (car dp) ":\n"))
-	    (setq fp (sort (vm-delete-backup-file-names
-			    (vm-delete-auto-save-file-names
-			     (vm-delete-index-file-names
-			      (vm-delete-directory-names
-			       (directory-files (car dp))))))
-			   (function string-lessp)))
+	    (let ((default-directory (car dp)))
+	      (setq fp (sort (vm-delete-backup-file-names
+			      (vm-delete-auto-save-file-names
+			       (vm-delete-index-file-names
+				(vm-delete-directory-names
+				 (directory-files (car dp))))))
+			     (function string-lessp))))
 	    (while fp
 	      (setq f (car fp)
 		    key (vm-make-folders-summary-key f (car dp))
